# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import enum

import winrt.system
from winrt._winrt_windows_phone_system_power import (
    PowerManager,
)

__all__ = [
    "PowerSavingMode",
    "PowerManager",
]

class PowerSavingMode(enum.IntEnum):
    OFF = 0
    ON = 1




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation

from winrt.windows.phone.system.power import PowerSavingMode

Self = typing.TypeVar('Self')

@typing.final
class PowerManager_Static(winrt._winrt.IInspectable_Static):
    # Windows.Foundation.EventRegistrationToken Windows.Phone.System.Power.PowerManager::add_PowerSavingModeChanged(Windows.Foundation.EventHandler`1<System.Object>)
    def add_power_saving_mode_changed(cls, change_handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.Phone.System.Power.PowerManager::remove_PowerSavingModeChanged(Windows.Foundation.EventRegistrationToken)
    def remove_power_saving_mode_changed(cls, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Phone.System.Power.PowerSavingMode Windows.Phone.System.Power.PowerManager::get_PowerSavingMode()
    @_property
    def power_saving_mode(cls) -> PowerSavingMode: ...
    # System.Boolean Windows.Phone.System.Power.PowerManager::get_PowerSavingModeEnabled()
    @_property
    def power_saving_mode_enabled(cls) -> bool: ...

@typing.final
class PowerManager(winrt.system.Object, metaclass=PowerManager_Static):
    pass

